# BOED (Bayesian Optimal Experiment Design)

::: inspeqtor.boed

::: inspeqtor.boed.safe_shape

::: inspeqtor.boed.report_shape

::: inspeqtor.boed.lexpand

::: inspeqtor.boed.random_split_index

::: inspeqtor.boed.AuxEntry

::: inspeqtor.boed.vectorized

::: inspeqtor.boed.marginal_loss

::: inspeqtor.boed.vnmc_eig_loss

::: inspeqtor.boed.init_params_from_guide

::: inspeqtor.boed.HistoryEntry

::: inspeqtor.boed.opt_eig_ape_loss

::: inspeqtor.boed.estimate_eig

::: inspeqtor.boed.vectorized_for_eig

::: inspeqtor.boed.marginal_init_params_fn

::: inspeqtor.boed.marginal_guide

::: inspeqtor.boed.auto_marginal_guide
